@@ -3,7 +3,7 @@
 # est.rf.R
 #
 # copyright (c) 2001-2010, Karl W Broman
-# last modified Jul, 2010
+# last modified Oct, 2010
 # first written Apr, 2001
 #
 #     This program is free software; you can redistribute it and/or
@@ -19,7 +19,7 @@
 #     at http://www.r-project.org/Licenses/GPL-3
 # 
 # Part of the R/qtl package
-# Contains: est.rf, plot.rf, checkAlleles
+# Contains: est.rf, plot.rf, checkAlleles, pull.rf, plot.rfmatrix
 #
 ######################################################################
 
@@ -341,4 +341,92 @@ function(cross, threshold=3, verbose=TRUE)
   results[results[,4] >= threshold,]
 }
 
+######################################################################
+# pull.rf
+#
+# pull out the pairwise marker recombination fraction estimates,
+# with class "rfmatrix"
+######################################################################
+
+pull.rf <- 
+function(cross, what=c("rf", "lod"), chr)
+{
+  if(!("cross" %in% class(cross)))
+    stop("Input must have class \"cross\".")
+  
+  if(!missing(chr)) cross <- subset(cross, chr=chr)
+
+  if(!("rf" %in% names(cross))) {
+    warning(" -Running est.rf")
+    cross <- est.rf(cross)
+  }
+  rf <- cross$rf
+  if(nrow(rf) != totmar(cross) || ncol(rf) != totmar(cross) ||
+     any(rownames(rf) != markernames(cross)) ||
+     any(colnames(rf) != markernames(cross))) {
+    warning(" -Rec. frac. estimates seem corrupted; re-running est.rf")
+    cross <- est.rf(cross)
+  }
+  rf <- cross$rf
+
+  diag(rf) <- NA
+  what <- match.arg(what)
+  if(what=="rf") 
+    rf[upper.tri(rf)] <- t(rf)[upper.tri(rf)]
+  else
+    rf[lower.tri(rf)] <- t(rf)[lower.tri(rf)]
+
+  attr(rf, "map") <- pull.map(cross, as.table=TRUE)
+  attr(rf, "what") <- what
+  class(rf) <- c("rfmatrix", "matrix")
+  rf
+}
+
+######################################################################
+# plot.rfmatrix:
+#
+# plot a slice through the matrix (that is, for one marker)
+######################################################################
+
+plot.rfmatrix <- 
+function(x, marker, ...)
+{
+  if(!("rfmatrix" %in% class(x)))
+    stop("Input must have class \"rfmatrix\".")
+
+  if(missing(marker))
+    stop("You must provide a marker name.")
+
+  if(length(marker) > 1) {
+    warning("Ignoring all but the first marker, ", marker[1])
+    marker <- marker[1]
+  }
+
+  if(!(marker %in% rownames(x)))
+    stop("Marker ", marker, " not found.")
+
+  what <- attr(x, "what")
+  x <- cbind(attr(x, "map"), x[marker,])
+  x$chr <- factor(x$chr, levels=unique(x$chr))
+                  
+  # fill in hole
+  wh <- which(rownames(x)==marker)
+  if(wh > 1 && wh < nrow(x) && x[wh-1,1] == x[wh,1] && x[wh+1,1] == x[wh,1]) {
+    xl <- x[wh-1,2]
+    xm <- x[wh,2]
+    xr <- x[wh+1,2]
+    yl <- x[wh-1,3]
+    yr <- x[wh+1,3]
+    x[wh,3] <- yl + (xm-xl)*(yr-yl)/(xr-xl)
+  }
+
+  colnames(x)[3] <- what
+  class(x) <- c("scanone", "data.frame")
+
+  plot(x, ...)
+  
+  invisible(x)
+}
+
+
 # end of est.rf.R
