@@ -2,8 +2,8 @@
 #
 # scantwo.R
 #
-# copyright (c) 2001-2010, Karl W Broman and Hao Wu
-# last modified Jul, 2010
+# copyright (c) 2001-2011, Karl W Broman and Hao Wu
+# last modified Feb, 2011
 # first written Nov, 2001
 #
 #     This program is free software; you can redistribute it and/or
@@ -121,19 +121,19 @@ function(cross, chr, pheno.col=1,
   if(any(pheno.col < 1 | pheno.col > nphe(cross)))
     stop("pheno.col values should be between 1 and the no. phenotypes")
 
-  # if stepwidth="variable" when calling calc.genoprob or sim.geno,
+  # if stepwidth="variable" or stepwidth=="max" when calling calc.genoprob or sim.geno,
   # we force incl.markers=TRUE; I assume it is the same for all chromosomes
   stepwidth.var <- FALSE
   if(method=="em" || method=="hk") {
     if("stepwidth" %in% names(attributes(cross$geno[[1]]$prob)) &&
-       attr(cross$geno[[1]]$prob, "stepwidth") == "variable") {
+       attr(cross$geno[[1]]$prob, "stepwidth") != "fixed") {
       stepwidth.var <- TRUE
       incl.markers <- TRUE
     }
   }
   else if(method=="imp") {
     if("stepwidth" %in% names(attributes(cross$geno[[1]]$draws)) &&
-       attr(cross$geno[[1]]$draws, "stepwidth") == "variable") {
+       attr(cross$geno[[1]]$draws, "stepwidth") != "fixed") {
       stepwidth.var <- TRUE
       incl.markers <- TRUE
     }
@@ -222,8 +222,8 @@ function(cross, chr, pheno.col=1,
   }
 
   # multiple phenotype for methods other than imp and hk
-  if(length(pheno.col)>1 && n.perm <= 0 &&
-     method!="imp" && method != "hk" ) {
+  if(length(pheno.col)>1 && n.perm <= 0 && (model != "normal" ||
+     (method!="imp" && method != "hk"))) {
     n.phe <- length(pheno.col)
     if(verbose) cat(" -Phenotype 1\n")
     output <- scantwo(cross, pheno.col=pheno.col[1], model=model,
@@ -1448,6 +1448,7 @@ function(n.perm, cross, pheno.col, model,
   ##     stratification is within those groups
   batch.mode <- FALSE
   if( (n.phe==1) && ((method=="imp") || (method=="hk")) &&
+     model=="normal" && 
      is.null(addcovar) && is.null(intcovar) ) {
     chrtype <- sapply(cross$geno, class)
     sexpgm <- getsex(cross)
